﻿using System;
using Telerik.Windows.Controls.ScheduleView;
using System.Windows;

namespace SilverlightApplication1
{
	public class WeeklyTickProvider : DependencyObject, ITickProvider
	{
		public static readonly DependencyProperty CurrentDateProperty =
			DependencyProperty.Register(
			"CurrentDate", typeof(DateTime),
			typeof(WeeklyTickProvider), null
			);

		public DateTime CurrentDate
		{
			get { return (DateTime)GetValue(CurrentDateProperty); }
			set { SetValue(CurrentDateProperty, value); }
		}

		public static readonly DependencyProperty VisibleDaysProperty =
			DependencyProperty.Register(
			"VisibleDays", typeof(int),
			typeof(WeeklyTickProvider), null
			);

		public int VisibleDays
		{
			get { return (int)GetValue(VisibleDaysProperty); }
			set { SetValue(VisibleDaysProperty, value); }
		}


		public string GetFormatString(IFormatProvider formatInfo, string formatString, DateTime currentStart)
		{
			var start = currentStart.Date;
			var end = this.GetNextStart(TimeSpan.Zero /*not used, see below*/, currentStart).AddSeconds(-1);

			if (this.CurrentDate > start && this.CurrentDate < end)
				start = this.CurrentDate;

			var viewEnd = this.CurrentDate.AddDays(this.VisibleDays).AddSeconds(-1);

			if (viewEnd < end)
				end = viewEnd;

			return string.Format(formatInfo, "{0:dd/MMMM/yyyy} - {1:dd/MMMM/yyyy}", start, end);
		}

		public DateTime GetNextStart(TimeSpan pixelLength, DateTime currentStart)
		{
			var currentDate = currentStart.Date;

			var weekStart = CalendarHelper.GetFirstDayOfWeek(currentStart, DayOfWeek.Tuesday);
			if (weekStart == currentDate)
			{
				return weekStart.AddDays(7);
			}
			return weekStart;
		}
	}
}